@@ -20,12 +20,13 @@ class SanityTest:
   port = None
   app_name = None
 
-  def __init__(self, tomcat_port, app_name):
+  def __init__(self, tomcat_port, app_name, sanity_test_timeout_sec=120):
     """
      @param tomcat_port - an HTTP port to access the web server where application is
     """
     self.port = int(tomcat_port)
     self.app_name = app_name
+    self.sanity_test_timeout_sec = sanity_test_timeout_sec
     if app_name == "ROOT":
       self.app_name = ""
 
@@ -35,7 +36,7 @@ class SanityTest:
     request_address = "http://{0}:{1}/{2}".format(self.HOST, self.port, self.app_name)
     self.logger.info("Running sanity tests to check whether application started correctly and responds back..")
     self.logger.info("Connecting to {0}", request_address)
-    response = requests.get(request_address, timeout=120)
+    response = requests.get(request_address, timeout=self.sanity_test_timeout_sec)
     if response.status_code not in [200, 201]:
       self.logger.error("While accessing main page, app answered with error: [{0} {1} {2}]",
                         response.status_code, response.reason, response.text)
